==> haskell-yesod-test-1.6.9-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-test.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-test
version: 1.6.9
id: yesod-test-1.6.9-BIwJklUw8J2LfnNov3kF3D
key: yesod-test-1.6.9-BIwJklUw8J2LfnNov3kF3D
license: MIT
maintainer: Michael Snoyman, Greg Weber, Nubis <nubis@woobiz.com.ar>
author: Nubis <nubis@woobiz.com.ar>
stability: Experimental
homepage: http://www.yesodweb.com
synopsis: integration testing for WAI/Yesod Applications
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-test>
category: Web, Yesod, Testing
abi: 36634728c0132ebf9f91cac6638a2a77
exposed: True
exposed-modules:
    Yesod.Test Yesod.Test.CssQuery Yesod.Test.TransversingCSS
import-dirs: /usr/lib/ghc-8.6.5/site-local/yesod-test-1.6.9
library-dirs: /usr/lib/ghc-8.6.5/site-local/yesod-test-1.6.9
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/yesod-test-1.6.9
hs-libraries: HSyesod-test-1.6.9-BIwJklUw8J2LfnNov3kF3D
depends:
    HUnit-1.6.0.0-JbqplLUCHWj8gC9WuQWK9
    aeson-1.4.6.0-53gmO5YtU8gIZiWG8EtnAc
    attoparsec-0.13.2.3-BbILE9CT2Wt3O8KWGStqZj base-4.12.0.0
    blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC
    blaze-html-0.9.1.2-HwoBmHvd8MidwTYIDsO4n bytestring-0.10.8.2
    case-insensitive-1.2.1.0-L7BR5PaOPZy5cAHpLYQKhk
    conduit-1.3.1.2-E2wpiTRwNV9HimJJXCCytL containers-0.6.0.1
    cookie-0.4.5-G7Q94cRAamcIKEZucf4yoC
    hspec-core-2.7.1-885e7phFBQnJ4twaYTfwQ5
    html-conduit-1.3.2.1-6X7II6zuR9AEcVlNx4m5Gm
    http-types-0.12.3-KiHBR3VW7LN81D4RBDuP1U
    memory-0.14.18-BrsHMbfyYBXCzXvPhAexth
    network-2.8.0.0-GWaLTJJGEavAfd7Abho21R
    pretty-show-1.9.5-4s9IVBWSe01IF3L4DDRCg8 text-1.2.3.1 time-1.8.0.2
    transformers-0.5.6.2 wai-3.2.2.1-LiO6tjlOPxLE7Ud9tulQOy
    wai-extra-3.0.28-Icu1vR7RUHVK69GXvXtucs
    xml-conduit-1.8.0.1-Crn3vtM8f1YCMk06gSbrAG
    xml-types-0.3.6-56MQ2lbfiw31ognZ51DOah
    yesod-core-1.6.17-52rC1KCMvTmIQUJtyjAi78
haddock-interfaces: /usr/share/doc/haskell-yesod-test/html/yesod-test.haddock
haddock-html: /usr/share/doc/haskell-yesod-test/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-test-1.6.9-10-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-test.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-test
version: 1.6.9
id: yesod-test-1.6.9-4EWO4hNccLtDdhoDS5UDOG
key: yesod-test-1.6.9-4EWO4hNccLtDdhoDS5UDOG
license: MIT
maintainer: Michael Snoyman, Greg Weber, Nubis <nubis@woobiz.com.ar>
author: Nubis <nubis@woobiz.com.ar>
stability: Experimental
homepage: http://www.yesodweb.com
synopsis: integration testing for WAI/Yesod Applications
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-test>
category: Web, Yesod, Testing
abi: 870f2ae5cc6740a984f4b0dc1e3d7fa8
exposed: True
exposed-modules:
    Yesod.Test Yesod.Test.CssQuery Yesod.Test.TransversingCSS
import-dirs: /usr/lib/ghc-8.6.5/site-local/yesod-test-1.6.9
library-dirs: /usr/lib/ghc-8.6.5/site-local/yesod-test-1.6.9
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/yesod-test-1.6.9
hs-libraries: HSyesod-test-1.6.9-4EWO4hNccLtDdhoDS5UDOG
depends:
    HUnit-1.6.0.0-F7HqWS6YZw9Ctb1uJk5Q8g
    aeson-1.4.6.0-IYkWE2kAqOg3BtypRoad0s
    attoparsec-0.13.2.3-7zk58GWWjTj9W2Qd2JktwB base-4.12.0.0
    blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC
    blaze-html-0.9.1.2-3rCj4yYYlH244V10MP4Bb5 bytestring-0.10.8.2
    case-insensitive-1.2.1.0-L7BR5PaOPZy5cAHpLYQKhk
    conduit-1.3.1.2-H13fTqo9FiUDKKswU2xRAM containers-0.6.0.1
    cookie-0.4.5-G7Q94cRAamcIKEZucf4yoC
    hspec-core-2.7.1-2ODfdracvB89FGpuKtnkLt
    html-conduit-1.3.2.1-3gOGqCBcbQF13BVUxlQjiI
    http-types-0.12.3-2tcDIAoQ8De6A4nb7F3Iw
    memory-0.14.18-BrsHMbfyYBXCzXvPhAexth
    network-2.8.0.0-LvSlvEKiGr81Yl4BCXERfa
    pretty-show-1.9.5-4s9IVBWSe01IF3L4DDRCg8 text-1.2.3.1 time-1.8.0.2
    transformers-0.5.6.2 wai-3.2.2.1-L0mqQcd6qdzCEAAdCddmDK
    wai-extra-3.0.28-JGmYG7rnTVLKrrO9cXdf2Z
    xml-conduit-1.8.0.1-9q9NXZW6IXpIQ3AgbfH6QL
    xml-types-0.3.6-56MQ2lbfiw31ognZ51DOah
    yesod-core-1.6.17-1OMyK8vEw156wqMBAguR6
haddock-interfaces: /usr/share/doc/haskell-yesod-test/html/yesod-test.haddock
haddock-html: /usr/share/doc/haskell-yesod-test/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
